@@ -129,7 +129,11 @@ extern int	       ctlsticky __((char *spec_host,char *addr_host));
 extern char           *notaryacct __((int rc, char *okstr));
 		/* NOTARY: addres / action / status / diagnostic  */
 extern void 	       notaryreport __((const char*,const char*,const char*,const char*));
+#if defined(HAVE_STDARG_H)
+extern void	       diagnostic __(( struct rcpt *, int, int, char *, ... ));
+#else
 extern void	       diagnostic __((/* struct rcpt *, int, int, char *,... */));
+#endif
 
 /* dnsgetrr.c */
 extern int	getrr     __((char *, int, int, int));
@@ -161,13 +165,17 @@ extern int ermdir __((char *path));
 extern int erename __((char *from, char *to));
 
 /* lockaddr.c: */
-extern int lockaddr __((int fd, char *map, long offset, char was, char new));
+extern int lockaddr __((int fd, char *map, long offset, int was, int new));
 
 /* markoff.c: */
 extern int markoff __((char *filecontents, int bytesleft, long offsets[], char *filename));
 
 /* mimeheaders.c: */
+#if defined(HAVE_STDARG_H)
+extern int append_header __((struct rcpt *rp, char *fmt, ...));
+#else
 extern int append_header __(());
+#endif
 extern struct cte_data *parse_content_encoding __((char **cte_linep));
 extern struct ct_data  *parse_content_type __((char **ct_linep));
 extern void output_content_type __((struct rcpt *rp, struct ct_data *ct, char **oldpos));
@@ -192,3 +200,6 @@ extern char *buildboundary __((char *what));
 
 extern int getout;
 extern RETSIGTYPE wantout __(());
+
+/* warning.c */
+extern int warning __(());
