@@ -45,6 +45,15 @@ initline(blksize)
 	getline_blen = 0;
 }
 
+void
+repos_getline(fp,newpos)
+	FILE *fp;
+	long newpos;
+{
+	getline_blen = 0;
+	fseek(fp, newpos, 0);
+}
+
 /*
  * Return the number of bytes starting from linebuf, which make up a line.
  */
