@@ -12,15 +12,6 @@
 #include <sys/param.h>
 #endif
 
-#ifdef	USE_SETUIDX	/* IBM AIXism */
-# include <sys/id.h>
-# ifdef  USE_SETREUID
-#  define setreuid(x,y) setuidx(ID_REAL|ID_EFFECTIVE, y)
-# else
-#  define setuid(y) setuidx(ID_REAL|ID_EFFECTIVE, y)
-# endif
-#endif
-
 /*
  * Routine to initialize the 'nobody' variable to contain a nonprivileged uid.
  *
@@ -86,17 +77,7 @@ getnobody()
 	/* check that we can setuid(nobody) */
 	i = -1;
 	while (nobodies[++i] != 0) {
-		if (
-#ifdef	USE_SETREUID
-		    setreuid(-1, nobodies[i])
-#else	/* !USE_SETREUID */
-#ifdef	USE_SETEUID
-		    seteuid(nobodies[i])
-#else	/* !USE_SETEUID */
-		    setuid(nobodies[i])
-#endif	/* USE_SETEUID */
-#endif	/* USE_SETREUID */
-					== 0)
+		if (setreuid(-1, nobodies[i]) == 0)
 			break;
 	}
 
@@ -105,17 +86,7 @@ getnobody()
 		fprintf(stderr, "Cannot determine 'nobody' uid\n");
 		exit(2);
 	}
-	if (
-#ifdef	USE_SETREUID
-	    setreuid(-1, 0)
-#else	/* !USE_SETREUID */
-#ifdef	USE_SETEUID
-	    seteuid(0)
-#else	/* !USE_SETEUID */
-	    setuid(0)
-#endif	/* !USE_SETEUID */
-#endif	/* USE_SETREUID */
-				    < 0 || getuid() != 0) {
+	if (setreuid(-1, 0) < 0 || getuid() != 0) {
 		perror("setuid");
 		fprintf(stderr, "Cannot reset root uid\n");
 		exit(3);
