@@ -258,14 +258,14 @@ struct token * scan822(cpp, n, c1, c2, allowcomments, tlistp)
 				while (--n > 0 && (rfc_ctype[*++cp] & _l))
 					continue;
 				strcpy(msgbuf,
-					"too many newlines (LFs) in field");
+					"too many newlines (LFs) in field[1]");
 				MKERROR(msgbuf,tlist);
 			}
 			t.t_type = Fold;
 		} else if (ct & _l) {	/* >= 1 LFs without CR is a fold too */
 			while (--n > 0 && (rfc_ctype[*++cp] & _l))
 				continue;
-			strcpy(msgbuf,"too many newlines (LFs) in field");
+			strcpy(msgbuf,"too many newlines (LFs) in field[2]");
 			MKERROR(msgbuf,tlist);
 			t.t_type = Fold;
 		} else if ((ct & _s) && (*cp=='(' || *cp=='"' || *cp=='[')) {
