@@ -19,8 +19,10 @@
 
 extern char *fullname();
 extern char *getenv();
+#ifndef strchr
 extern char *strchr();
 extern char *strrchr();
+#endif
 extern char *whathost();
 extern int errno;
 
@@ -433,3 +435,87 @@ mail_close(fp)
 	mail_free(message);
 	return 0;
 }
+
+/*
+ * Close the message file on the indicated stream, and submit
+ * it to the SCHEDULER. (For smtpserver->scheduler messages.)
+ */
+
+int
+mail_close_scheduler(fp)
+	FILE *fp;
+{
+	char **messagep, *message, *nmessage, *msgbase;
+	char *transportdir;
+	int eno;
+
+	if (postoffice == NULL) {
+		fprintf(stderr, "mail_close: called out of order!\n");
+		errno = EINVAL;
+		return -1;
+	}
+	if (fp == NULL) {
+		errno = EBADF;
+		return -1;
+	}
+	if (FILENO(fp) >= mail_nfiles)
+		abort();
+	messagep = &mail_file[FILENO(fp)];
+	if (*messagep == NULL) {
+		errno = ENOENT;
+		return -1;
+	}
+
+	message = *messagep;
+	*messagep = NULL;
+
+	/*
+	 * *** NFS users beware ***
+	 * the fsync() between fflush() and fclose() may be mandatory
+	 * on NFS mounted postoffices if you want to guarantee not losing
+	 * data without being told about it.
+	 */
+	if (fflush(fp) == EOF
+/* #ifdef NFSFSYNC */ /* This is propably ALWAYS a good idea */
+	    || fsync(FILENO(fp)) < 0
+/* #endif */	/* NFSFSYNC */
+	    || fclose(fp) == EOF) {
+		mail_free(message);
+		errno = EIO;
+		return -1;
+	}
+
+
+	/* Find the base name (we know format is PUBLICDIR/basename) */
+	if ((msgbase = strrchr(message, '/')) == NULL)
+		msgbase = message;
+	else
+		++msgbase;
+
+	transportdir = TRANSPORTDIR;
+	nmessage  = NULL;
+	/* Assert postoffice != NULL */
+	nmessage = mail_alloc(strlen(postoffice)+
+			      strlen(transportdir)+strlen(msgbase)+2+1);
+	sprintf(nmessage, "%s/%s/%s", postoffice, transportdir, msgbase);
+
+	/*
+	 * Unfortunately, rename() doesn't guarantee the same inode will
+	 * be used if the two paths are on the same filesystem, so we do
+	 * it the hard way.
+	 */
+
+	if (link(message, nmessage) < 0) {
+		eno = errno;
+		fprintf(stderr, "link(\"%s\", \"%s\"): errno %d\n",
+				message, nmessage, errno);
+		mail_free(message);
+		mail_free(nmessage);
+		errno = eno;
+		return -1;
+	}
+	mail_free(nmessage);
+	unlink(message);
+	mail_free(message);
+	return 0;
+}
