@@ -2,6 +2,7 @@
  * Several 'setreuid()' replacements for those systems that
  * don't have it, or have it under different names...
  */
+#include "hostenv.h"
 
 /*
  * From Ross Ridge's Xenix port:
@@ -65,6 +66,24 @@ uid_t ruid, euid;
 #endif
 }
 
+#else
+#ifdef HAVE_SETEUID	/* Pure SysVR4 ? */
+int setreuid(ruid, euid)
+     uid_t ruid, euid;
+{
+	/* THIS IS NOT PURE IMPLEMENTATION! */
+	/* INTENTION IS TO PROVIDE SOMETHING WORKABLE
+	   WITHOUT TOO COMPLEX A PROGRAM... */
+
+	int rc = 0;
+	if (euid >= 0) {
+	  rc = seteuid(euid);
+	  if (ruid < 0)
+	    return rc;
+	}
+	if (ruid >= 0)
+	  return setuid(ruid);
+}
 #else
 #ifdef	__hpux
 #include <sys/types.h>
@@ -231,4 +250,5 @@ main() {
 static int foovar = 0; /* some systems want something into .o -file */
 #endif /* Not SYSV */
 #endif /* Not SYSV, not __hpux */
+#endif /* HAVE_SETEUID */
 #endif /* Not AIX either.. */
