@@ -5,11 +5,9 @@
  *	Also Guy Middleton, and Matti Aarnio have hacked this piece -- 1993
  *
  *	In 1996 Matti Aarnio <mea@nic.funet.fi> converted this to GNU autoconf
- *
+ *	and did serious rewriteing...
  */
 
-/* XXX: Some of these routines have memory leakage! */
-
 /*LINTLIBRARY*/
 
 #include "hostenv.h"
@@ -52,8 +50,11 @@
 extern char *strchr();
 #endif
 
-/* Sort of 'forward' definition */
-static char	*getmntpt();
+#ifndef	MAXHOSTNAMELEN
+#define	MAXHOSTNAMELEN 64
+#endif	/* MAXHOSTNAMELEN */
+
+static char	hostname[MAXHOSTNAMELEN+1];
 
 
 /*
@@ -61,13 +62,14 @@ static char	*getmntpt();
  * for the file system it lives in, or NULL in case of any error.
  */
 #ifdef MOUNTED_GETMNT /* Ultrix */
-static char *
-getmntpt(file, dir)
-	char	*file, **dir;
+char *
+whathost(file)
+	char	*file;
 {
 	int	mountind, nummount;
 	static struct fs_data	mounts[1];
 	struct stat	filestat, dirstat;
+	char *s;
 
 	if (stat(file, &filestat) < 0) {
 		perror(file);
@@ -77,25 +79,30 @@ getmntpt(file, dir)
 	while ((nummount = getmountent(&mountind, mounts, 1)) > 0) {
 		if ((stat(mounts[0].fd_path, &dirstat) >= 0) &&
 		   (filestat.st_dev == dirstat.st_dev)) {
-			*dir = mounts[0].fd_path;
-			return mounts[0].fd_devname;
+			strncpy(hostname,hmounts[0].fd_devname,sizeof(hostname));
+			hostname[sizeof(hostname)-1] = 0;
+			s = strchr(hostname,':');
+			if (s != NULL) {
+			  *s = 0;
+			  return hostname;
+			}
+			return "localhost";
 		}
 	}
 	if (nummount == -1)
 		perror("Can't get mount information");
 	return NULL;
 }
-#endif
-
+#else
 #ifdef MOUNTED_GETMNTINFO /* DEC OSF/1 */
-static char *
-getmntpt(file, dir)
-	char	*file, **dir;
+char *
+whathost(file)
+	char	*file;
 {
 	int	nummount, i;
 	struct	statfs *mounts;
-	static struct statfs mntfs;
-	struct stat	filestat, dirstat;
+	struct  stat    filestat, dirstat;
+	char *s;
 
 	if (stat(file, &filestat) < 0) {
 		perror(file);
@@ -107,51 +114,49 @@ getmntpt(file, dir)
 		perror("Can't get mount information");
 		return NULL;
 	}
-
+	*hostname = 0;
 	for (i=0; i<nummount; i++) {
-		if ((stat(mounts[i].f_mntonname, &dirstat) >= 0) &&
-		   (filestat.st_dev == dirstat.st_dev)) {
-			memcpy(&mntfs, &mounts[i], sizeof mntfs);
-			*dir = mntfs.f_mntonname;
-			return mntfs.f_mntfromname;
-		}
+	  if ((stat(mounts[i].f_mntonname, &dirstat) >= 0) &&
+	      (filestat.st_dev == dirstat.st_dev)) {
+	    s = strchr(mounts[i].f_mntfromname, ':');
+	    if (s != NULL) {
+	      *s = 0;
+	      strncpy(hostname,mounts[i].f_mntfromname,sizeof(hostname));
+	      hostname[sizeof(hostname)-1] = 0;
+	      if (strncmp(s+1,"(pid",4) == 0) {
+		/* Umm.. Most likely this is an automount mountpoint!
+		   Lets try to find the real one, if we can! */
+		continue;
+	      }
+	      free(mounts);
+	      return hostname;
+	    } else {
+	      free(mounts);
+	      return "localhost";
+	    }
+	  }
 	}
+	free(mounts);
+	if (*hostname != 0)
+	  return hostname;
 	return NULL;
 }
-#endif
-
-#if defined(MOUNTED_GETMNTENT1) || defined(MOUNTED_GETMNTENT2)
-static char *
-getmntpt(file, dir)
-	char	*file, **dir;
+#else
+#ifdef MOUNTED_GETMNTENT1
+char *
+whathost(file)
+	char	*file;
 {
 	FILE	*mntp;
 	MNTTYPE	*mnt;
 	static MNTTYPE	rmnt;
 	struct stat	filestat, dirstat;
+	char *s;
 
 	if (stat(file, &filestat) < 0) {
 		perror(file);
 		return(NULL);
 	}
-#ifdef	MOUNTED_GETMNTENT2
-	mnt = &rmnt;
-	if ((mntp = fopen(MNTTAB, "r")) == NULL) {
-		perror(MNTTAB);
-		return(NULL);
-	}
-	while (getmntent(mntp, mnt) == 0) {
-		if (strcmp(mnt->mnt_fstype, MNTTYPE_SWAP) == 0)
-			continue;
-		if ((stat(mnt->mnt_mountp, &dirstat) >= 0) &&
-		   (filestat.st_dev == dirstat.st_dev)) {
-			fclose(mntp);
-			*dir = mnt->mnt_mountp;
-			return mnt->mnt_special;
-		}
-	}
-	fclose(mntp);
-#else /* MOUNTED_GETMNTENT1 */
 	if ((mntp = setmntent(MOUNTED, "r")) == NULL) {
 		perror(MOUNTED);
 		return(NULL);
@@ -162,17 +167,72 @@ getmntpt(file, dir)
 			continue;
 		if ((stat(mnt->mnt_dir, &dirstat) >= 0) &&
 		   (filestat.st_dev == dirstat.st_dev)) {
+			s = strchr(mnt->mnt_fsname,':');
+			if (s != NULL) {
+			  *s = 0;
+			  strncpy(hostname,mnt->mnt_fsname,sizeof(hostname)-1);
+			  hostname[sizeof(hostname)-1] = 0;
+			} else
+			    strcpy(hostname,"localhost");
 			endmntent(mntp);
-			*dir = mnt->mnt_dir;
-			return mnt->mnt_fsname;
+			return hostname;
 		}
 	}
 	endmntent(mntp);
-#endif
 	return NULL;
 }
-#endif
+#else
+#ifdef MOUNTED_GETMNTENT2
+char *
+whathost(file)
+	char	*file;
+{
+	FILE	*mntp;
+	MNTTYPE	*mnt;
+	static MNTTYPE	rmnt;
+	struct stat	filestat, dirstat;
+	char *s;
 
+	if (stat(file, &filestat) < 0) {
+		perror(file);
+		return(NULL);
+	}
+	mnt = &rmnt;
+	if ((mntp = fopen(MNTTAB, "r")) == NULL) {
+		perror(MNTTAB);
+		return(NULL);
+	}
+	*hostname = 0;
+	while (getmntent(mntp, mnt) == 0) {
+	  if (strcmp(mnt->mnt_fstype, MNTTYPE_SWAP) == 0)
+	    continue;
+	  if ((stat(mnt->mnt_mountp, &dirstat) >= 0) &&
+	      (filestat.st_dev == dirstat.st_dev)) {
+	    /* So ok, filestat matches, but it may be an automount/autofs
+	       mountpoint, try to recognize it too */
+	    s = strchr(mnt->mnt_special,':');
+	    if (s != NULL) {
+	      *s = 0;
+	      strncpy(hostname,mnt->mnt_special,sizeof(hostname)-1);
+	      hostname[sizeof(hostname)-1] = 0;
+	      if (strcmp(mnt->mnt_fstype,"autofs") == 0 /* Solaris */ ||
+		  strncmp(s+1,"(pid",4) == 0 /* Other automounters */ )
+		continue;
+	    } else {
+	      strcpy(hostname,"localhost");
+	      if (strcmp(mnt->mnt_fstype, "autofs") == 0)
+		continue;
+	    }
+	    fclose(mntp);
+	    return hostname;
+	  }
+	}
+	fclose(mntp);
+	if (*hostname != 0)
+	  return hostname;
+	return NULL;
+}
+#else
 #if defined(MOUNTED_VMOUNT) /* AIX */
 
 /* Much of the following code is from GNU fileutils 3.13 */
@@ -187,11 +247,6 @@ whathost(file)
 	struct vmount *vmp;
 	char *dir, *host;
 
-#ifndef	MAXHOSTNAMELEN
-#define	MAXHOSTNAMELEN 64
-#endif	/* MAXHOSTNAMELEN */
-	static char	hostname[MAXHOSTNAMELEN+1];
-
 	/* Stat the file, is it a regular file, or a directory ? */
 	if (stat(file, &statb) < 0)
 		return NULL;
@@ -252,29 +307,10 @@ whathost(file)
 
 #else	/* Not AIX -- all other systems .. */
 
-char *
-whathost(file)
-	char	*file;
-{
-	struct stat	statb;
-	char		*mnt, *cp, *dir;
-#ifndef	MAXHOSTNAMELEN
-#define	MAXHOSTNAMELEN 64
-#endif	/* MAXHOSTNAMELEN */
-	static char	hostname[MAXHOSTNAMELEN+1];
-
-	if (stat(file, &statb) < 0)
-		return NULL;
-	if ((statb.st_mode & S_IFMT & (S_IFREG|S_IFDIR))
-	    && (mnt = getmntpt(file, &dir)) != NULL) {
-		if ((cp = strchr(mnt, ':')) == 0)
-			return "localhost";
-		/* file is remote - use locking daemon! */
-		*cp++ = '\0';
-		strcpy(hostname, mnt);
-		return hostname;
-	}
-	return NULL;
-}
+error:error:error: Unknown/unimplemented filesystem mount-info method
 
 #endif
+#endif
+#endif
+#endif
+#endif
