@@ -43,7 +43,7 @@ unsigned short ident_tcpport = 113;
 
 #define SIZ 500 /* various buffers */
 
-static clearsa(sa)
+static void clearsa(sa)
 struct sockaddr_in *sa;
 {
  register char *x;
