@@ -54,7 +54,8 @@ extern struct osCmd avcmd;
 extern struct spblk *sp_lookup();
 extern struct sptree *spt_builtins;
 extern struct sptree *spt_funclist;
-extern void assign(), ioop(), trapped(), jc_report();
+extern void assign(), trapped(), jc_report();
+extern void ioop __((OutputTokens,struct osCmd *,u_char *,int,int,u_char *));
 extern void freeTokens();
 extern void trapexit();
 extern void v_export(), v_sync();
@@ -648,8 +649,8 @@ runcommand(c, pc, retcodep)
 				freeio(c->doio, 1);
 				c->doio = NULL;
 			}
-			ioop(sIOintoBuffer, ib_command[ibt], (u_char *)NULL,
-				O_CREAT|O_WRONLY|O_TRUNC, 1, (u_char *)NULL);
+			ioop(sIOintoBuffer, ib_command[ibt], NULL,
+			     O_CREAT|O_WRONLY|O_TRUNC, 1, NULL);
 			/* Now copy doio and execio to current command */
 			/* first doio */
 #if 0
@@ -717,7 +718,8 @@ assign(sl_lhs, sl_rhs, command)
 {
 	register struct conscell *s, *l, *tmp;
 	u_char *varname;
-	int oval, freerhs;
+	int freerhs;
+	memtypes oval;
 
 	oval = stickymem;
 	stickymem = MEM_MALLOC;
@@ -1155,7 +1157,7 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 	char	*origlevel;
 	int	*iname;
 	int	argi1, dye, childpid, dollar, ioflags;
-	int	stickytmp, origstickymem;
+	memtypes stickytmp, origstickymem;
 	int	defaultfd, quote, quoted, nloop, ignore_level;
 #define LOOPMAXDEPTH 30
 	struct loopinfo loop[LOOPMAXDEPTH];	/* max # nested loops */
@@ -1223,7 +1225,7 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 	origlevel = getlevel(MEM_SHCMD);
 	stickymem = MEM_SHCMD;
 	/* shut up the compiler */
-	stickytmp = 0;
+	stickytmp = MEM_SHCMD;;
 	d = NULL;
 	argi1 = 0;
 
@@ -1368,8 +1370,7 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 					    && command->sfdp == NULL) {
 						/* create pipe for prev. cmd */
 						ioop(sIOopenPipe, prevcommand,
-							(u_char*)0,O_CREAT,1,
-							(u_char*)0);
+						     NULL, O_CREAT, 1, NULL);
 						/* --- */
 						RUNIO(prevcommand->doio);
 						freeio(prevcommand->doio, 1);
@@ -1377,8 +1378,7 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 						/* --- */
 						/* add inpipe to this command */
 						ioop(sIOopenPipe, command,
-							(u_char*)0,O_RDONLY,0,
-							(u_char*)0);
+						     NULL, O_RDONLY, 0, NULL);
 					} else if (command->sfdp != NULL
 					    || (command->shcmdp != NULL
 					        && (command->shcmdp->sptr != NULL
@@ -1430,12 +1430,12 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 				command->argv = newcell();
 				command->argv->flags = 0;
 				command->argv->pflags = 0;
-				command->argv->prev = 0;
+				command->argv->prev = NULL;
 				cdr(command->argv) = NULL;
 				car(command->argv) = newcell();
 				car(command->argv)->flags = 0;
 				car(command->argv)->pflags = 0;
-				car(command->argv)->prev = 0;
+				car(command->argv)->prev = NULL;
 				cdar(command->argv) = NULL;
 				caar(command->argv) = d;
 				cdar(command->argv) = s_last(d);
@@ -1452,8 +1452,8 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 					command->iocmd = ioPipeOutput;
 				} else {
 					command->reaperTop = reapableTop;
-					ioop(sIOopenPipe, command, (u_char *)0,
-							  O_CREAT, 1, 0);
+					ioop(sIOopenPipe, command,
+					     NULL, O_CREAT, 1, NULL);
 				}
 			}
 			if (isset('I'))
@@ -1553,8 +1553,7 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 						command->reaperTop =
 							reapableTop;
 						ioop(sIOopenPipe, command,
-							(u_char *)0,O_CREAT,1,
-							(u_char *)0);
+						     NULL, O_CREAT, 1, NULL);
 					}
 				}
 				if (command->doio != NULL) {
@@ -2154,7 +2153,7 @@ std_printf("found %x at %d\n", re, argi1-1);
 			re = NULL;
 			if (command->buffer != NULL) {
 				if (cdr(command->buffer)) {
-					int stickytmp = stickymem;
+					memtypes stickytmp = stickymem;
 					stickymem = MEM_PERM;
 					d = s_catstring(command->buffer);
 					stickymem = stickytmp;
@@ -2305,7 +2304,7 @@ std_printf("found %x at %d\n", tre, argi1-1);
 			tre = NULL;
 			if (command->buffer != NULL) {
 			  if (cdr(command->buffer)) {
-			    int stickytmp = stickymem;
+			    memtypes stickytmp = stickymem;
 			    stickymem = MEM_PERM;
 			    d = s_catstring(command->buffer);
 			    stickymem = stickytmp;
@@ -2439,7 +2438,7 @@ getout:
 		--commandIndex;
 	}
 
-/* #define RETVAL_FREEUP /* yes or no.. undefine if problems.. */
+/* #define RETVAL_FREEUP */ /* yes or no.. undefine if problems.. */
 
 #ifndef	RETVAL_FREEUP	/* The original way ... */
 	setlevel(MEM_SHCMD, origlevel);
@@ -2514,7 +2513,7 @@ getout:
 	if (cdp->functions == NULL) {
 		if (cdp->rearray != NULL) {
 			while (cdp->rearray_idx >= 0)
-				free_regexp((char *)cdp->rearray[cdp->rearray_idx--]);
+				free_regexp(cdp->rearray[cdp->rearray_idx--]);
 			free((char *)cdp->rearray);
 		}
 		if (cdp->trearray != NULL) {
@@ -2569,7 +2568,8 @@ lapply(fname, l)
 	char *fname;
 	struct conscell *l;
 {
-	int retcode = -123456, oval;
+	int retcode = -123456;
+	memtypes oval;
 	struct sslfuncdef *sfdp;
 	struct spblk *spl;
 	struct osCmd avc;
