@@ -65,7 +65,7 @@ optimize(print, code, eocodep)
 			progname, (int)(*eocodep - code));
 		return code;
 	}
-	bzero(bitmap,(coderange)/8+1);
+	memset(bitmap, 0, (coderange)/8+1);
 #else /* Not  USE_ALLOCA */
 	if ((addrmap = (int *)malloc((coderange) * sizeof(int))) == NULL
 	    || (bitmap = (char *)calloc((coderange)/8+1, 1)) == NULL) {
