@@ -24,7 +24,7 @@
 
 #include "prototypes.h"
 
-struct sptree *spt_databases;
+extern struct sptree *spt_databases; /* At conf.c */
 
 /*
  * The following tables describes the kinds of lookups we support.
