@@ -29,8 +29,8 @@
 #ifdef __linux__
 #define __USE_BSD 1	/* Linux headers ... Auch..  <endian.h> */
 #endif
-#include "arpa/nameser.h"
-#include "resolv.h"
+#include <arpa/nameser.h>
+#include <resolv.h>
 #include "search.h"
 
 #ifdef	__alpha		/* The IP-address processing must be changed to
@@ -157,7 +157,9 @@ extern int deferit, res_init(), cistrcmp();
 extern void die(), v_set();
 extern char *dottedquad();
 extern int res_mkquery(), res_send(), dn_expand(), dn_skipname();
+#ifndef strchr
 extern char *strchr();
+#endif
 
 
 void
@@ -300,17 +302,17 @@ getmxrr(host, localhost, ttlp, depth)
 	  return NULL;
 	}
 	qlen = res_mkquery(QUERY, host, C_IN, T_MX, NULL, 0, NULL,
-			   (unsigned char *)&buf, sizeof(buf));
+			   (void *)&buf, sizeof(buf));
 	if (qlen < 0) {
 		fprintf(stderr, "search_res: res_mkquery (%s) failed\n", host);
 		strcpy(h_errhost, host);	/* use strcat on purpose */
 		h_errno = NO_RECOVERY;
 		return NULL;
 	}
-	n = res_send((void *)&buf, qlen, (unsigned char *)&answer, sizeof(answer));
+	n = res_send((void *)&buf, qlen, (void *)&answer, sizeof(answer));
 	if (n < 0) {
 	  /* Retry it ONCE.. */
-	  n = res_send((void *)&buf, qlen, (unsigned char *)&answer, sizeof(answer));
+	  n = res_send((void *)&buf, qlen, (void *)&answer, sizeof(answer));
 	  if (n < 0) {
 	    if (D_bind || _res.options & RES_DEBUG)
 	      fprintf(stderr,
@@ -531,7 +533,7 @@ getrrtype(host, rrtype, ttlp, depth)
 	}
 
 	qlen = res_mkquery(QUERY, host, C_IN, rrtype, NULL, 0, NULL,
-			   (unsigned char *)&buf, sizeof(buf));
+			   (void *)&buf, sizeof(buf));
 	if (qlen < 0) {
 		if (D_bind || _res.options & RES_DEBUG)
 			fprintf(stderr,
@@ -540,10 +542,10 @@ getrrtype(host, rrtype, ttlp, depth)
 		h_errno = NO_RECOVERY;
 		return NULL;
 	}
-	n = res_send((void *)&buf, qlen, (unsigned char *)&answer, sizeof(answer));
+	n = res_send((void *)&buf, qlen, (void *)&answer, sizeof(answer));
 	if (n < 0) {
 	  /* Retry it ONCE.. */
-	  n = res_send((void*)&buf, qlen, (unsigned char *)&answer, sizeof(answer));
+	  n = res_send((void*)&buf, qlen, (void *)&answer, sizeof(answer));
 	  if (n < 0) {
 	    if (D_bind || _res.options & RES_DEBUG)
 	      fprintf(stderr,
