@@ -10,7 +10,9 @@
 #include "search.h"
 #include "io.h"
 
+#ifndef strchr
 extern char *strchr();
+#endif
 extern int cistrcmp();
 extern struct sptree *spt_headers, *spt_eheaders;
 extern void sp_null();
@@ -46,7 +48,7 @@ struct headerinfo optional_hdrs[] = {
 { "resent-date",	DateTime,	nilUserType,	Resent		},
 { "encrypted",		Encrypted,	nilUserType,	normal		},
 { "errors-to",		AddressList,	Sender,		normal		},
-{ "keywords",		PhraseList,	nilUserType,	normal		},
+/* { "keywords",	PhraseList,	nilUserType,	normal	    }, */
 { "obsoletes",		MessageIDList,	nilUserType,	normal		},
 { "references",		References,	nilUserType,	normal		},
 #if 0
@@ -57,6 +59,7 @@ struct headerinfo optional_hdrs[] = {
 
 struct headerinfo envelope_hdrs[] = {
 { "authinfo",	nilHeaderSemantics,	nilUserType,	eIdentinfo	},
+{ "bodytype",	nilHeaderSemantics,	nilUserType,	eBodytype	},
 { "channel",		AnyWord,	nilUserType,	eChannel	},
 { "env-end",	nilHeaderSemantics,	nilUserType,	eEnvEnd		},
 { "env-eof",	nilHeaderSemantics,	nilUserType,	eEnvEnd		},
@@ -135,7 +138,8 @@ void
 init_header()
 {
 	struct headerinfo rh, *rhp;
-	int i, oval;
+	int i;
+	memtypes oval;
 
 	oval = stickymem;
 	for (i = 0; i < (sizeof mandatory_hdrs / sizeof mandatory_hdrs[0]); ++i) {
@@ -292,7 +296,7 @@ add_header(sip, value)
 {
 	struct sptree *db;
 	struct spblk *spl;
-	int oval;
+	memtypes oval;
 	char *cp;
 	struct headerinfo rh, *rhp;
 
