@@ -58,11 +58,19 @@ reopen:
 	key.dsize = strlen((char *)(sip->key)) + 1;
 	val = dbm_fetch(db, key);
 	if (val.dptr == NULL) {
+#ifdef HAVE_DBM_ERROR
 		if (!retry && dbm_error(db)) {
 			dbm_close(db);
 			++retry;
 			goto reopen;
 		}
+#else
+		if (!retry && errno != 0) {
+			dbm_close(db);
+			++retry;
+			goto reopen;
+		}
+#endif
 		return NULL;
 	}
 	us = (u_char *)strnsave(val.dptr, val.dsize);
@@ -199,8 +207,13 @@ print_ndbm(sip, outfp)
 		val = dbm_fetch(db, key);
 		if (val.dptr == NULL)
 			continue;
+#ifdef HAVE_DBM_ERROR
 		if (dbm_error(db))
 			break;
+#else
+		if (errno != 0)
+			break;
+#endif
 		if (*(char*)val.dptr == '\0')
 			fprintf(outfp, "%s\n", key.dptr);
 		else
@@ -227,8 +240,13 @@ count_ndbm(sip, outfp)
 	    val = dbm_fetch(db, key);
 	    if (val.dptr == NULL)
 	      continue;
+#ifdef HAVE_DBM_ERROR
 	    if (dbm_error(db))
 	      break;
+#else
+	    if (errno != 0)
+	      break;
+#endif
 	    ++cnt;
 	}
 	fprintf(outfp,"%d\n",cnt);
