@@ -51,7 +51,9 @@ search_bin(sip)
 	symid = symbol((u_char *)sip->file);
 	spl = sp_lookup(symid, spt_files);
 	if (spl == NULL || (fm = (struct file_map *)spl->data) == NULL) {
+#ifndef HAVE_MMAP
 reopen:
+#endif
 		fp = fopen(sip->file, "r");
 		if (fp == NULL) {
 			++deferit;
@@ -76,8 +78,8 @@ reopen:
 		  fm->membuf = NULL;
 		if ((long)fm->membuf == -1) {
 			fprintf(stderr,
-				"search_bin: cannot mmap() (r/o) %d bytes of file \"%s\" into memory, errno=%d",
-				fst.st_size, sip->file, errno);
+				"search_bin: cannot mmap() (r/o) %ld bytes of file \"%s\" into memory, errno=%d",
+				(long)fst.st_size, sip->file, errno);
 			free(fm);
 			++deferit;
 			v_set(DEFER, DEFER_IO_ERROR);
