@@ -53,7 +53,6 @@ int	D_alloc = 0;
 extern char **hp_getaddr(), **hp_nextaddr();
 extern char *qoutputfile;
 extern char *strerror();
-extern char *strchr(), *strrchr();
 extern char *whathost(), *dottedquad();
 extern int errno, pokedaemon();
 extern int isalive();
@@ -76,8 +75,8 @@ int	debug, verbose, summary, user, status, onlyuser, nonlocal, schedq;
 
 time_t	now;
 
-char	*optarg;
-int	optind;
+extern char *optarg;
+extern int   optind;
 char	path[MAXPATHLEN];
 
 int
@@ -338,7 +337,7 @@ main(argc, argv)
 	  fcntl(fd, F_SETFL, dsflag);
 	  pokedaemon(pid);
 	  /* XX: reset uid in case we are suid - we need to play games */
-	  sleep(1);		/* this makes it work reliably. WHY??! */
+	  sleep(1);		/* this makes it work reliably. WHY ?! */
 	  docat((char *)NULL, fd);
 	} else
 #endif	/* S_IFIFO */
