@@ -22,8 +22,6 @@
 
 #include "prototypes.h"
 
-extern char *strchr();
-extern char *strrchr();
 #ifndef strnsave /* unless it is a debugging macro.. */
 extern char *strnsave();
 #endif
@@ -207,11 +205,15 @@ reporterrs(cfpi)
 	char *dnsrecipient = NULL;
 	struct ctlfile *cfp;
 	char *rcpntpointer;
+	int no_error_report = 0;
 
 	if (cfpi->haderror == 0)
 		return;
 	if (cfpi->erroraddr == NULL)
 		return;
+	if (cfpi->errorchan != NULL &&
+	    strcmp(cfpi->errorchan,"error") == 0)
+		no_error_report = 1;
 
 	boundarystr = (char*)buildboundary("dlvryerr");
 
@@ -259,26 +261,30 @@ reporterrs(cfpi)
 	      eaddr = "postmaster"; /* Paranoid, eh ? */
 	    fprintf(errfp, "channel error\n");
 
-	    fprintf(errfp, "to <%s>\n", eaddr);
+	    if (!no_error_report)
+	      fprintf(errfp, "to <%s>\n", eaddr);
 	    sprintf(path, "%s/%s/%s", mailshare, FORMSDIR,
 		    deliveryform ? deliveryform : "delivery");
 	    if ((fp = fopen(path, "r")) != NULL) {
 	      int inhdr = 1;
 	      buf[sizeof(buf)-1] = 0;
 	      while (fgets(buf,sizeof(buf)-1,fp) != NULL) {
-		if (strncmp(buf,"HDR",3)==0)
+		if (strncmp(buf,"HDR",3)==0) {
 		  continue;
-		else if (strncmp(buf,"ADR",3)==0)
+		} else if (strncmp(buf,"ADR",3)==0) {
+		  if (no_error_report)
+		    no_error_report = -1;
 		  pick_env_addr(buf+4,errfp);
-		else if (strncmp(buf,"SUB",3)==0)
+		} else if (strncmp(buf,"SUB",3)==0) {
 		  continue;
-		else
+		} else
 		  break;
 	      }
 	      fputs("env-end\n",errfp); /* Envelope ends */
 	      fseek(fp,0,0);		/* Rewind! Start building the report */
 
-	      fprintf(errfp, "To: %s\n", eaddr);
+	      if (no_error_report == 0)
+		fprintf(errfp, "To: %s\n", eaddr);
 	      while (fgets(buf,sizeof(buf)-1,fp) != NULL) {
 		if (strncmp(buf,"HDR",3)==0) {
 		  fputs(buf+4,errfp);
@@ -445,7 +451,10 @@ reporterrs(cfpi)
 	/* And cap the tail with paired MIME boundary.. */
 	fprintf(errfp, "--%s--\n", boundarystr);
 
-	mail_close(errfp);	/* XX: check for error */
+	if (no_error_report > 0)
+	  mail_abort(errfp);
+	else
+	  mail_close(errfp);	/* XX: check for error */
 	close(cfp->fd);
 	cfp->mid = NULL; /* we don't want to loose the original one! */
 	free_cfp_memory(cfp);
