@@ -28,16 +28,14 @@ static int qpchannel();
 static int qphost();
 extern char *saytime();
 
-#ifdef	HAVE_UTIMES
-#include <sys/time.h>
-#else	/* !HAVE_UTIMES */
-/*#include <unistd.h> */
-/* some systems have utimbuf defined in unistd.h, some don't... */
-struct utimbuf {
-	time_t	actime;
-	time_t	modtime;
-};
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
 #endif	/* !HAVE_UTIMES */
+#ifdef HAVE_UTIME_H
+# include <utime.h>
+#else
+/* XXX: struct utimbuf defined ??? */
+#endif
 
 static FILE *qpfp;
 static char qpch;
@@ -49,10 +47,10 @@ void
 qprint(fd)
 	int fd;
 {
-#ifdef	HAVE_UTIMES
-	struct timeval tvp[2];
-#else	/* !HAVE_UTIMES */
+#ifdef	HAVE_UTIME
 	struct utimbuf tvp;
+#else	/* !HAVE_UTIMES */
+	struct timeval tvp[2];
 #endif	/* !HAVE_UTIMES */
 
 	/*
@@ -105,13 +103,13 @@ qprint(fd)
 	/* XX: I suppose we don't really need to do this if we use TCP. */
 	if (rendezvous != NULL) {
 	  time_t now = mytime(NULL) - 1;
-#ifdef	HAVE_UTIMES
+#ifdef	HAVE_UTIME
+	  tvp.actime = tvp.modtime = now;
+	  utime(rendezvous, &tvp);
+#else	/* !HAVE_UTIMES */
 	  tvp[0].tv_sec = tvp[1].tv_sec = now;
 	  tvp[0].tv_usec = tvp[1].tv_usec = 0;
 	  utimes(rendezvous, tvp);
-#else	/* !HAVE_UTIMES */
-	  tvp.actime = tvp.modtime = now;
-	  utime(rendezvous, &tvp);
 #endif	/* !HAVE_UTIMES */
 	}
 }
