@@ -69,7 +69,7 @@ struct conshell *envarlist = NULL;
 				  need open -- or any of its children.. */
 int	transportmaxnofiles = TRANSPORTMAXNOFILES; /* Default value */
 char	*progname;
-char	*postoffice;
+extern char *postoffice;	/* At  mail_open()  */
 char	*rendezvous;
 char	*pidfile = PID_SCHEDULER;
 char	*mailshare;
@@ -118,8 +118,6 @@ static RETSIGTYPE sig_readcf __((int sig));
 extern char *Version;
 extern char *optarg;
 extern char *strerror __((int errno));
-extern char *strchr  /* __((char *s, char c)); */ ();
-extern char *strrchr /* __((char *s, char c)); */ ();
 extern int cistrcmp __((char *s1, char *s2));
 extern int efstat __((int fd, struct stat *stbuf));
 extern int emkdir __((char *dirpath, int mode));
@@ -135,7 +133,7 @@ extern time_t mytime __((time_t *));
 static void init_timeserver __((void));
 
 #ifdef HAVE_SELECT /* Well, not exactly kosher assumption.. */
-extern int gettimeofday();
+/* extern int gettimeofday __((struct timeval *,)); */
 #else
 extern time_t time __((time_t *));
 #endif
@@ -218,6 +216,7 @@ struct ctlfile *cfp;
 	if (cfp->contents)	free(cfp->contents);
 	if (cfp->mid)		free(cfp->mid);
 	if (cfp->erroraddr)	free(cfp->erroraddr);
+	if (cfp->errorchan)	free(cfp->errorchan);
 	if (cfp->logident)	free(cfp->logident);
 	if (cfp->envid)		free(cfp->envid);
 	free((char *)cfp);
@@ -1058,6 +1057,7 @@ static struct ctlfile *vtxprep(cfp)
 	char *cp, *channel, *host, *l_channel, *l_host;
 	char *echannel, *ehost, *l_echannel, *l_ehost, mfpath[100], flagstr[2];
 	char *latest_sender = NULL;
+	char *senderchannel = NULL;
 	struct spblk *spl;
 	struct vertex *vp, *pvp, **pvpp, *head;
 	struct stat stbuf;
@@ -1120,12 +1120,17 @@ static struct ctlfile *vtxprep(cfp)
 	    case _CF_SENDER:
 	      ++cp;
 	      while (*cp == ' ') ++cp;
-	      while (*cp != 0 && *cp != ' ') ++cp; while (*cp == ' ') ++cp;
+	      senderchannel = cp;
+	      while (*cp != 0 && *cp != ' ') ++cp; 
+	      if (*cp == ' ') *cp++ = 0;
+	      while (*cp == ' ') ++cp;
 	      while (*cp != 0 && *cp != ' ') ++cp; while (*cp == ' ') ++cp;
 	      latest_sender = cp;
 	      while (*cp != 0 && *cp != ' ') ++cp;  *cp = 0; /* We assume: No spaces at the sender addr! */
 	      if (cfp->erroraddr)  free(cfp->erroraddr);
 	      cfp->erroraddr = strsave(latest_sender);
+	      if (cfp->errorchan)  free(cfp->errorchan);
+	      cfp->errorchan = strsave(senderchannel);
 	      break;
 	    case _CF_RECIPIENT:
 	      if (opcnt >= offspc-1) {
