@@ -73,6 +73,7 @@ struct ctlfile {
 	struct vertex	*head;		/* head of the list of groups	     */
 	int	nlines;		/* number of lines/entries in the file	     */
 	char	*erroraddr;	/* error address(es)			     */
+	char	*errorchan;	/* error channel -- to detect 'MAIL FROM:<>' */
 	char	*contents;	/* the control file as copied into memory    */
 	char	*logident;	/* identification for log entries	     */
 	char	*deliveryform;	/* [mea] Name of delivery error form	     */
@@ -177,5 +178,3 @@ struct vertex {
 	int		ngroup;		/* number of addresses in group      */
 	int		index[1];	/* index of cfp->offset for group    */
 };
-
-extern char		*strcpy(), *strncpy(), *strcat();
