@@ -583,9 +583,12 @@ web_disentangle(vp, ok)
 	  delete_thread(vp->thread, ok);
 }
 
-static int vtx_ctime_cmp(a, b)
-struct vertex **a, **b;
+static int vtx_ctime_cmp(ap, bp)
+     const void *ap, *bp;
 {
+	const struct vertex **a = (const struct vertex **)ap;
+	const struct vertex **b = (const struct vertex **)bp;
+
 	if ((*a)->cfp->ctime < (*b)->cfp->ctime)
 	  return -1;
 	else if ((*a)->cfp->ctime == (*b)->cfp->ctime)
@@ -1345,6 +1348,20 @@ if (verbose) printf("idle_cleanup()\n");
 	return freecount;
 }
 
+static time_t oldest_age_on_thread(th) /* returns the AGE in seconds.. */
+struct thread *th;
+{
+	register time_t oo = now+1;
+	register struct vertex *vp;
+
+	vp = th->vertices;
+	while (vp) {
+	  if (vp->cfp->ctime < oo)
+	    oo = vp->cfp->ctime;
+	  vp = vp->nextitem;
+	}
+	return (now - oo);
+}
 
 void thread_report(fp)
 FILE *fp;
@@ -1373,6 +1390,7 @@ FILE *fp;
 	  struct procinfo *p;
 	  struct thread *thr;
 	  int thr_once = 1;
+	  time_t oldest;
 
 	  thg_once = 0;
 	  fprintf(fp,"%s/%s/%d\n",
@@ -1382,27 +1400,44 @@ FILE *fp;
 	  jobsum = 0;
 	  thr_once = 1;
 	  for (thr = thg->thread; thr && (thr_once || thr != thg->thread); thr = thr->nextthg) {
+	    int width;
+	    width = fprintf(fp,"\t%s/%s/%d",
+			    /* thr->vertices->orig[L_CHANNEL]->name, */ thr->channel,
+			    /* thr->vertices->orig[L_HOST]->name, */ thr->host,
+			    thr->thgrp->withhost);
+	    if (width == EOF) return;
+	    width += 7;
+	    if (width < 16-1)
+	      putc('\t',fp);
+	    if (width < 24-1)
+	      putc('\t',fp);
+	    if (width < 32-1)
+	      putc('\t',fp);
+	    if (width < 40-1)
+	      putc('\t',fp);
+	    else
+	      putc(' ',fp);
 	    thr_once = 0;
-
-	    fprintf(fp,"\t%s/%s/%d\trcpts=%d",
-		    /* thr->vertices->orig[L_CHANNEL]->name, */ thr->channel,
-		    /* thr->vertices->orig[L_HOST]->name, */ thr->host,
-		    thr->thgrp->withhost,thr->jobs);
 	    jobsum += thr->jobs;
-	    fprintf(fp," ats=%d",thr->attempts);
+	    fprintf(fp,"R=%-2d", thr->jobs);
+	    fprintf(fp," A=%-2d",thr->attempts);
 	    ++cnt;
 	    if (thr->proc != NULL &&
 		thr->proc->thread == thr) {
 	      ++procs;
-	      fprintf(fp," pid=%d",thr->proc->pid);
-	      fprintf(fp," hage=%ds",(now - thr->proc->hungertime));
+	      fprintf(fp," P=%-5d",thr->proc->pid);
+	      fprintf(fp," HA=%ds",(now - thr->proc->hungertime));
 	      if (thr->proc->feedtime == 0)
-		fprintf(fp," fage=never");
+		fprintf(fp," FA=never");
 	      else
-		fprintf(fp," fage=%ds",(now - thr->proc->feedtime));
-	      fprintf(fp," ofed=%d", thr->proc->overfed);
+		fprintf(fp," FA=%ds",(now - thr->proc->feedtime));
+	      fprintf(fp," OF=%-2d", thr->proc->overfed);
 	    } else if (thr->wakeup > now)
-	      fprintf(fp," wakeup=%d",(int)(thr->wakeup - now));
+	      fprintf(fp," W=%ds",(int)(thr->wakeup - now));
+	    *timebuf = 0;
+	    saytime((long)oldest_age_on_thread(thr), timebuf, 1);
+	    fprintf(fp," QA=%s", timebuf);
+
 	    if (thr->vertices && thr->vertices->ce_pending)
 	      fprintf(fp,
 		      thr->vertices->ce_pending == SIZE_L ? "" :
