@@ -61,7 +61,6 @@ struct procinfo *cpids = NULL;
 int	numkids = 0;
 
 extern char *getzenv();
-extern char *strchr();
 extern int errno;
 
 
@@ -584,7 +583,10 @@ time_t timeout;
 	fd_set	wrmask;
 	struct timeval tv;
 
-	if (in_select) fprintf(stderr,"**** recursed into mux()! ***\n");
+	if (in_select) {
+	  fprintf(stderr,"**** recursed into mux()! ***\n");
+	  return 0;
+	}
 	in_select = 1;
 
 	mytime(&now);
