@@ -16,7 +16,6 @@
 #include <sys/stat.h>
 #include "mail.h"
 #include "scheduler.h"
-#include NDIR_H
 
 #include "prototypes.h"
 
@@ -25,8 +24,6 @@ static int ctlowner __((struct ctlfile *));
 static void vtxupdate __((struct vertex *, int, int));
 static void expaux __((struct vertex *, int, char *));
 
-extern char *strchr();
-extern char *strrchr();
 extern int ermdir();
 extern int rmdir();
 extern int eunlink();
