@@ -1,5 +1,5 @@
 /*
- *	Copyright 1994 Matti Aarnio
+ *	Copyright 1994-1996 Matti Aarnio
  *	This is part of the ZMailer (2.99+), and available with
  *	the rules of the main program itself
  */
@@ -11,32 +11,18 @@
 #include <sys/param.h>
 
 
-#ifdef	HAVE_STATVFS
+#ifdef	HAVE_SYS_STATVFS_H
 # include <sys/statvfs.h>
-# define FSTATFS fstatvfs
-#else	/* !HAVE_STATVFS */
-#if defined(SYSV) || defined(_AIX)
+#endif	/* !HAVE_STATVFS */
+#ifdef HAVE_SYS_STATFS_H
 # include <sys/statfs.h>
-# define FSTATFS fstatfs /* Existence of this means (usually) SYSV code */
-#else /* Hmm.. Assuming it appears on all NON-SysV systems.. */
-#ifdef ULTRIX
-	/* From: James S MacKinnon <jmack@Phys.UAlberta.Ca> */
+#endif
+#ifdef HAVE_SYS_MOUNT_H
 # include <sys/mount.h>
-# include <netinet/in.h>
-# include <nfs/nfs_clnt.h>
-# include <nfs/vfs.h>
-# define FSTATFS statfs	/* Existence of this means (usually) SYSV code */
-#else /* !ULTRIX */
-#ifdef BSD4_4
-# include <sys/mount.h>
-/* # define FSTATFS fstatfs */ /* nonexistence of this means BSD code */
-#else /* !BSD4_4 */
+#endif
+#ifdef HAVE_SYS_VFS_H
 # include <sys/vfs.h>
-/* # define FSTATFS fstatfs */ /* nonexistence of this means BSD code */
-#endif /* !BSD4_4 */
-#endif /* !ULTRIX */
-#endif /* !SYSV */
-#endif /* !HAVE_STATVFS */
+#endif
 
 long fd_statfs(fd)
 int fd;
@@ -55,18 +41,35 @@ int fd;
 	  availspace = statbuf.f_bavail * statbuf.f_frsize;
 	}
 #else
-#if defined(__linux__) || (defined(BSD4_4) && !defined(bsdi)) || \
-    defined(ULTRIX) || defined(_AIX)
+#ifdef STAT_STATFS3_OSF1
+	struct statfs statbuf;
+	if ((rc = fstatfs(fd, &statbuf, sizeof(statbuf))) == 0) {
+	  availspace = statbuf.f_bavail * statbuf.f_fsize;
+	}
+#else
+#ifdef STAT_STATFS2_BSIZE
 	struct statfs statbuf;
 	if ((rc = fstatfs(fd, &statbuf)) == 0) {
 	  availspace = statbuf.f_bavail * statbuf.f_bsize;
 	}
+#else
+#ifdef STAT_STATFS2_FSIZE
+	struct statfs statbuf;
+	if ((rc = fstatfs(fd, &statbuf)) == 0) {
+	  availspace = statbuf.f_bavail * statbuf.f_fsize;
+	}
+#else
+#ifdef STAT_STATFS2_FS_DATA /* Ultrix ? */
+	XX:XXX:XX:XXX:
 #else /* none of the previous  -- SVR3 stuff... */
 	struct statfs statbuf;
 	if ((rc = fstatfs(fd, &statbuf,sizeof statbuf, 0)) == 0){
 	  availspace = statbuf.f_bfree * statbuf.f_bsize;
 	}
 #endif
+#endif
+#endif
+#endif
 #endif
 	return availspace;
 }
