@@ -387,8 +387,9 @@ int strict;
 }
 
 static
-char *rfc821_dotnum(s)		/* <snum> "." <snum> "." <snum> "." <snum> */
+char *rfc821_dotnum(s,strict)	/* <snum> "." <snum> "." <snum> "." <snum> */
 char *s;
+int strict;
 {
 	int i,val,cnt;
 	char *p = s-1;
