@@ -13,20 +13,29 @@
 #include <fcntl.h>
 #include <pwd.h>
 #include <time.h>
-#ifdef HAVE_SYSLOG_H
+#ifdef HAVE_SYSLOG
 #include <syslog.h>
 #endif
-#include <tzfile.h>
+/* #include <tzfile.h> */  /* Not needed ? */
 #include <errno.h>
 #include <sysexits.h>
 #ifdef	HAVE_NDBM_H
 #include <ndbm.h>
 #include <fcntl.h>
+#else
+#ifdef  HAVE_GDBM_H
+#include <gdbm.h>
+#include <fcntl.h>
 #endif
-#include "useful.h"
-#include "userdbm.h"
+#endif
+/* #include "useful.h"  */
+/* #include "userdbm.h" */
 
-SCCSID(@(#)vacation.c	4.1		7/25/83);
+#ifndef LONG_MAX
+# define LONG_MAX 1000000000 /* 100 million seconds - 3.2 years */
+#endif
+
+/* SCCSID(@(#)vacation.c	4.1		7/25/83); */
 
 #undef VDEBUG
 
@@ -66,7 +75,9 @@ SCCSID(@(#)vacation.c	4.1		7/25/83);
 #define MAXLINE	1024		/* max size of a line */
 #define VDB	".vacation"
 #define VMSG	".vacation.msg"
+#ifndef VMSGDEF
 #define VMSGDEF "/usr/lib/vacation.def"
+#endif
 
 typedef struct alias {
 	struct alias *next;
@@ -74,17 +85,27 @@ typedef struct alias {
 } ALIAS;
 ALIAS *names = NULL;
 
-#ifdef	NDBM
+#ifdef	HAVE_NDBM_H
 DBM *db;
-#define DBT datum
+#else
+#ifdef HAVE_GDBM_H
+GDBM_FILE db;
+#endif /* GDBM */
 #endif	/* NDBM */
 
+#define DBT datum
+
 char from[MAXLINE];
 char *subject_str = NULL;	/* Glob subject from input */
 int dblog = 1;
 
 extern void purge_input();
 extern char *strerror();
+extern struct passwd *getpwnam();
+extern char *newstr();
+extern int optind, opterr;
+extern char *optarg;
+extern FILE *freopen(), *tmpfile();
 
 int
 main(argc, argv)
@@ -100,11 +121,6 @@ main(argc, argv)
 	char *msgfile = NULL;
 	char buf[MAXLINE];
 	int ch, iflag;
-	extern struct passwd *getpwnam();
-	extern char *newstr();
-	extern int optind, opterr;
-	extern char *optarg;
-
 
 	/* process arguments */
 	opterr = iflag = 0;
@@ -131,7 +147,7 @@ main(argc, argv)
 		  case 't':
 		  case 'r':
 			if (isdigit(*optarg)) {
-				interval = atol(optarg) * SECSPERDAY;
+				interval = atol(optarg) * (24*60*60);
 				if (interval < 0)
 					usage();
 			}
@@ -194,8 +210,15 @@ main(argc, argv)
 		db = dbm_open(VDB, O_RDWR | (iflag ? O_TRUNC|O_CREAT : 0),
 			      S_IRUSR|S_IWUSR);
 #else	/* !NDBM */
+#ifdef HAVE_GDBM_H
+	if (dblog)
+		db = gdbm_open(VDB ".pag" /* Catenates these strings */, 8192,
+			       iflag ? GDBM_NEWDB : GDBM_WRITER,
+			       S_IRUSR|S_IWUSR, NULL );
+#else
 	if (dblog)
 		db = dbinit(VDB); /* XX: old DBM ? */
+#endif
 #endif
 	if (dblog && !db) {
 		fprintf(stderr, "vacation: %s.* database file(s): %s\n", 
@@ -210,9 +233,14 @@ main(argc, argv)
 #ifdef	HAVE_NDBM_H
 		if (dblog)
 			dbm_close(db);
+#else
+#ifdef HAVE_GDBM_H
+		if (dblog)
+			gdbm_close(db);
 #else
 		if (dblog)
 			XX: eh, what ?
+#endif
 #endif
 		exit(EX_OK);
 	}
@@ -260,7 +288,6 @@ sendmessage(msgf, myname)
 	char linebuf[512];
 	char *s;
 	int  pp[2];
-	extern FILE *freopen(), *tmpfile();
 
 #ifdef VDEBUG
 	fprintf(stderr, "sendmessage(%s, %s)\n", msgf, myname);
@@ -277,6 +304,7 @@ sendmessage(msgf, myname)
 	if (f == NULL)
 		syserr("No message to send");
 	tmpf = tmpfile();
+	fprintf(tmpf,"To: %s\n", from);
 	while (!feof(f) && !ferror(f)) {
 	  if (fgets(linebuf,sizeof(linebuf),f) == NULL) break;
 	  if ((s = strchr(linebuf,'$')) != NULL) {
@@ -318,14 +346,10 @@ sendmessage(msgf, myname)
 **		none.
 */
 
-/* VARARGS 1 */
-usrerr(f, p)
-	char *f;
-	char *p;
+usrerr(msg)
+	char *msg;
 {
-	fprintf(stderr, "vacation: ");
-	_doprnt(f, &p, stderr);
-	fprintf(stderr, "\n");
+	fprintf(stderr, "vacation: %s\n",msg);
 }
 /*
 **  SYSERR -- print system error
@@ -342,13 +366,10 @@ usrerr(f, p)
 */
 
 /* VARARGS 1 */
-syserr(f, p)
-	char *f;
-	char *p;
+syserr(msg)
+	char *msg;
 {
-	fprintf(stderr, "vacation: ");
-	_doprnt(f, &p, stderr);
-	fprintf(stderr, "\n");
+	fprintf(stderr, "vacation: %s\n", msg);
 	exit(EX_USAGE+103);
 }
 /*
@@ -420,7 +441,7 @@ readheaders()
 				for (p = buf + 5; *p && *p != ' '; ++p);
 				*p = '\0';
 				strcpy(from, buf + 5);
-				if (p = index(from, '\n'))
+				if (p = strchr(from, '\n'))
 					*p = '\0';
 				if (junkmail()) {
 					purge_input();
@@ -433,7 +454,7 @@ readheaders()
 			if (strncasecmp(buf, "Precedence", 10) ||
 			    buf[10] != ':' && buf[10] != ' ' && buf[10] != '\t')
 				break;
-			if (!(p = index(buf, ':')))
+			if (!(p = strchr(buf, ':')))
 				break;
 			while (*++p && isspace(*p));
 			if (!*p)
@@ -508,7 +529,7 @@ junkmail()
 	} ignore[] = {
 		"-request", 8,		"postmaster", 10,	"uucp", 4,
 		"mailer-daemon", 13,	"mailer", 6,		"-relay", 6,
-		NULL, NULL,
+		NULL, 0
 	};
 	register struct ignore *cur;
 	register int len;
@@ -521,9 +542,9 @@ junkmail()
 	 *
 	 * From site!site!SENDER%site.domain%site.domain@site.domain
 	 */
-	if (!(p = index(from, '%')))
-		if (!(p = index(from, '@'))) {
-			if (p = rindex(from, '!'))
+	if (!(p = strchr(from, '%')))
+		if (!(p = strchr(from, '@'))) {
+			if (p = strrchr(from, '!'))
 				++p;
 			else
 				p = from;
@@ -560,7 +581,7 @@ purge_input()
 /*
  * recent --
  *	find out if user has gotten a vacation message recently.
- *	use bcopy for machines with alignment restrictions
+ *	use memcpy for machines with alignment restrictions
  */
 recent()
 {
@@ -572,18 +593,34 @@ recent()
 	/* get interval time */
 	key.dptr = VIT;
 	key.dsize = sizeof(VIT);
+#ifdef HAVE_NDBM_H
 	data = dbm_fetch(db, key);
+#else
+#ifdef HAVE_GDBM_H
+	data = gdbm_fetch(db, key);
+#else
+    XX:XX:XX:XX:XX:XX:XX:XX
+#endif
+#endif
 	if (data.dptr == NULL)
-		next = SECSPERDAY * DAYSPERWEEK;
+		next = (60*60*24*7); /* One week */
 	else
-		bcopy(data.dptr, &next, sizeof(next));
+		memcpy(&next, data.dptr, sizeof(next));
 
 	/* get record for this address */
 	key.dptr = from;
 	key.dsize = strlen(from);
+#ifdef HAVE_NDBM_H
 	data = dbm_fetch(db, key);
+#else
+#ifdef HAVE_GDBM_H
+	data = gdbm_fetch(db, key);
+#else
+    XX:XX:XX:XX:XX:XX:XX:XX
+#endif
+#endif
 	if (data.dptr) {
-		bcopy(data.dptr, &then, sizeof(then));
+		memcpy(&then, data.dptr, sizeof(then));
 		if (next == LONG_MAX || then + next > time(NULL))
 			return(1);
 	}
@@ -605,7 +642,14 @@ setinterval(interval)
 	key.dsize = sizeof(VIT);
 	data.dptr = (void*)&interval;
 	data.dsize = sizeof(interval);
+#ifdef HAVE_NDBM_H
 	dbm_store(db, key, data, DBM_REPLACE);
+#else
+#ifdef HAVE_GDBM_H
+	gdbm_store(db, key, data, GDBM_REPLACE);
+#else
+#endif
+#endif
 }
 
 /*
@@ -624,7 +668,14 @@ setreply()
 	time(&now);
 	data.dptr = (void*)&now;
 	data.dsize = sizeof(now);
+#ifdef HAVE_NDBM_H
 	dbm_store(db, key, data, DBM_REPLACE);
+#else
+#ifdef HAVE_GDBM_H
+	gdbm_store(db, key, data, GDBM_REPLACE);
+#else
+#endif
+#endif
 }
 
 usage()
@@ -632,14 +683,16 @@ usage()
 	fprintf(stderr,"vacation: [-i] [-d] [-a alias] [-m msgfile] [-r interval] login\n");
 	exit(EX_USAGE);
 }
-#ifndef HAVE_STRERROR
+
+#ifndef HAVE_STRERROR
+
+extern int sys_nerr;
+extern char *sys_errlist[];
+
 char *
 strerror(errno)
 int errno;
 {
-	extern int sys_nerr;
-	extern char *sys_errlist[];
-
 	if (errno < 1 || errno > sys_nerr) return "Unknown errno!";
 	return sys_errlist[errno];
 }
