@@ -15,6 +15,8 @@
 #else
 # include <varargs.h>
 #endif
+#include <sys/types.h>
+#include <sys/stat.h>
 #include "mail.h"
 #include "ta.h"
 
@@ -55,7 +57,7 @@ char *okstr;
 }
 
 static char *arg5 = NULL; /* NOTARY arg5: 'While-Talking-To -host' */
-notary_setwtt(host)
+void notary_setwtt(host)
 char *host;
 {
 	if (arg5) free(arg5);
@@ -108,7 +110,7 @@ diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remote
 #endif
 {
 	char	mark, message[8192];
-	register char *cp, *s, *es, *s2;
+	register char *s, *es, *s2;
 	va_list	ap;
 	int report_notary = 1;
 
