@@ -5,7 +5,7 @@
 
 #include <stdio.h>
 #include "hostenv.h"
-#ifdef	UTSNAME_H
+#ifdef	HAVE_SYS_UTSNAME_H
 #include <sys/utsname.h>
 #endif	/* UTSNAME_H */
 
@@ -15,7 +15,7 @@ getmyuucpname(namebuf, len)
 	int len;
 {
 	FILE *fp;
-#ifdef	UTSNAME_H
+#ifdef	HAVE_SYS_UTSNAME_H
 	struct utsname id;
 
 	if (uname(&id) < 0)
