@@ -14,6 +14,8 @@
 
 #include "hostenv.h"
 #include <stdio.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include "ta.h"
 
 int
