@@ -78,18 +78,19 @@ extern int wait();
 #include "dotlock.c"
 #endif
 
-#ifdef  HAVE_UTIMES
-#include <sys/time.h>
+#ifdef  HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+#ifdef HAVE_UTIME_H
+# include <utime.h>
 #else
-/* #include <unistd.h>  */
-/* some systems have utimbuf defined in unistd.h, some don't... */
+/* XXX: some systems have utimbuf defined in unistd.h, some don't... */
 struct utimbuf {
 	time_t  actime;
 	time_t  modtime;
 };
 #endif
 
-
 #ifndef	L_SET
 #define	L_SET	0
 #endif	/* !L_SET */
@@ -1110,18 +1111,18 @@ putmail(dp, rp, fdmail, fdopmode, timestring, file)
 	  if (!keepatime) st.st_atime = 0;
 
 	  if (st.st_atime != 0) {
-#ifdef	HAVE_UTIMES
+#ifdef	HAVE_UTIME
+	    struct utimbuf tv;
+	    tv.actime  = st.st_atime;
+	    tv.modtime = st.st_mtime;
+	    rc = utime(file, &tv);
+#else  /* HAVE_UTIMES */
 	    struct timeval tv[2];
 	    tv[0].tv_sec = st.st_atime;
 	    tv[1].tv_sec = st.st_mtime;
 	    tv[0].tv_usec = tv[1].tv_usec = 0;
 	    rc = utimes(file, tv);
-#else  /* !HAVE_UTIMES */
-	    struct utimbuf tv;
-	    tv.actime  = st.st_atime;
-	    tv.modtime = st.st_mtime;
-	    rc = utime(file, &tv);
-#endif /* !HAVE_UTIMES */
+#endif /* HAVE_UTIMES */
 	  }
 	} else if (eofindex > 0L && eofindex < (sizeof "From x\n")) {
 	  /* A mail message *cannot* be this small.  It must be
