@@ -230,8 +230,10 @@ extern univptr_t emalloc();
    extern long atol __((char*));
  */
 extern char *strerror();
+#ifndef strchr
 extern char *strchr();
 extern char *strrchr();
+#endif
 extern char *dottedquad();
 extern char *optarg;
 extern int optind;
@@ -252,7 +254,6 @@ extern int process __((struct ctldesc*,int,char*,FILE**,FILE*));
 extern int check_7bit_cleanness __((struct ctldesc *dp));
 extern void notarystatsave __((char *smtpstatline, char *status));
 
-extern void prversion();
 extern void getnobody();
 extern int makeconn __((struct hostent*, int*, FILE*, FILE**));
 extern int vcsetup __((char*,int,int*,char*,FILE*));
@@ -480,7 +481,7 @@ main(argc, argv, envp)
 	if (logfile != NULL) {
 	  if ((fd = open(logfile, O_CREAT|O_APPEND|O_WRONLY, 0644)) < 0)
 	    fprintf(stderr,
-		    "%s: cannot open logfile \"%s\"!\n",
+		    "#%s: cannot open logfile \"%s\"!\n",
 		    argv[0], logfile);
 	  else
 	    logfp = (FILE *)fdopen(fd, "a");
@@ -2015,7 +2016,7 @@ vcsetup(ipaddrcp, ipaddrlen, fdp, hostname, verboselog)
 /* setreuid(0,0); */
 	  *fdp = s;
 #if	defined(__svr4__) || defined(BSD) && (BSD-0) >= 43
-	  setsockopt(s, SOL_SOCKET, SO_KEEPALIVE, &on, sizeof on);
+	  setsockopt(s, SOL_SOCKET, SO_KEEPALIVE, (void*)&on, sizeof on);
 #else  /* BSD < 43 */
 	  setsockopt(s, SOL_SOCKET, SO_KEEPALIVE, 0, 0);
 #endif /* BSD >= 43 */
@@ -2332,6 +2333,7 @@ int smtp_sync(smtpfp,verboselog,r)
 	int some_ok = 0;
 	int err;
 	char buf[8192];
+	char *p;
 
 	alarm(timeout);
 	fflush(smtpfp[1]);
@@ -2350,7 +2352,7 @@ int smtp_sync(smtpfp,verboselog,r)
 	    ++eol; /* points to char AFTER the newline */
 	    if (debug && logfp)
 	      fprintf(logfp,"%s#\t(pipebufsize=%d, s=%d, eol=%d)\n",
-		      logtag(), pipebufsize,s-pipebuf,eol-pipebuf);
+		      logtag(), pipebufsize,(int)(s-pipebuf),(int)(eol-pipebuf));
 	  } else { /* No newline.. Read more.. */
 	    int en;
 	    err = select_sleep(infd, timeout);
@@ -2405,10 +2407,12 @@ int smtp_sync(smtpfp,verboselog,r)
 	      goto rescan_line;
 	    }
 	  } /* ... globbing more input */
+
+	  p = eol-1;		  /* The '\n' at the end of the line	*/
+	  if (p[-1] == '\r') --p; /* "\r\n" ?				*/
+	  *p = 0;
+
 	  if (logfp != NULL) {
-	    char *p = eol-1; /* The '\n' at the end of the line */
-	    if (p[-1] == '\r') --p;
-	    *p = 0;
 	    if (debug)
 	      putc('\n',logfp);
 	    fprintf(logfp,
@@ -2887,6 +2891,7 @@ matchmyaddress(addr,len)
 	int len;
 {
 	int i;
+	unsigned int ia; /* 32 bit address */
 
 	if (!myaddrs) return 0; /* Don't know my addresses ! */
 	
@@ -2897,11 +2902,14 @@ matchmyaddress(addr,len)
 	}
 	/* Also match loopback net.. */
 	if (len == 4) {
-	  unsigned int ia; /* 32 bit address */
 	  memcpy(&ia,addr,4);
+#ifndef INADDR_LOOPBACK /* FreeBSD does not have this in  <netinet/in.h> ! */
+# define INADDR_LOOPBACK 0x7f000001
+#endif
 	  if (IN_CLASSA(ntohl(ia)) &&
-	      (ntohl(ia) & IN_CLASSA_NET) == INADDR_LOOPBACK)
+	      (ntohl(ia) & IN_CLASSA_NET) == (IN_CLASSA_NET & INADDR_LOOPBACK)) {
 	    return 2;
+	  }
 	}
 	return 0;
 }
